"""add ods_marketing tables

Revision ID: c335441a4bf8
Revises: 2d7609e6f490
Create Date: 2025-03-01 18:23:12.992376

"""

import os

import sqlalchemy as sa
from alembic import op


# revision identifiers, used by Alembic.
revision = 'c335441a4bf8'
down_revision = '2d7609e6f490'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table_schema("ODS_MARKETING")
    op.create_table(
        'frontend_actions',
        sa.Column('uuid', sa.Uuid(), nullable=False),
        sa.Column('user_id', sa.Integer(), nullable=False),
        sa.Column('action', sa.String(), nullable=False, comment='Совершенное действие'),
        sa.Column('path_from', sa.String(), nullable=True, comment='Откуда совершен переход'),
        sa.Column('path_to', sa.String(), nullable=True, comment='Назначение перехода'),
        sa.Column('user_agent', sa.String(), nullable=True, comment='Информация об операционной системе и браузере'),
        sa.Column('is_bot', sa.Boolean(), nullable=False, comment='Флаг бот или нет'),
        sa.Column('create_ts', sa.DateTime(), nullable=False, comment='Таймстемп создания'),
        sa.PrimaryKeyConstraint('uuid'),
        schema='ODS_MARKETING',
        comment='Фронтендовые события',
        info={'sensitive': False},
    )
    op.create_table(
        'printer_actions',
        sa.Column('uuid', sa.Uuid(), nullable=False),
        sa.Column('action', sa.String(), nullable=False, comment='Совершенное действие'),
        sa.Column('path_from', sa.String(), nullable=True, comment='Откуда совершен переход'),
        sa.Column('path_to', sa.String(), nullable=True, comment='Назначение перехода'),
        sa.Column('status', sa.String(), nullable=False, comment='Статус действия'),
        sa.Column('app_version', sa.String(), nullable=False, comment='Версия приложения'),
        sa.Column('create_ts', sa.DateTime(), nullable=False, comment='Таймстемп создания (московское время)'),
        sa.PrimaryKeyConstraint('uuid'),
        schema='ODS_MARKETING',
        comment='Действия принтера',
        info={'sensitive': False},
    )
    op.create_table(
        'printer_bots_actions',
        sa.Column('uuid', sa.Uuid(), nullable=False),
        sa.Column('action', sa.String(), nullable=False, comment='Совершенное действие'),
        sa.Column('path_from', sa.String(), nullable=True, comment='Откуда совершен переход'),
        sa.Column('path_to', sa.String(), nullable=True, comment='Назначение перехода'),
        sa.Column('status', sa.String(), nullable=False, comment='Статус действия'),
        sa.Column('user_id', sa.Integer(), nullable=False, comment='Айди юзера в соответствующей соцсети(tg/vk)'),
        sa.Column('surname', sa.String(), nullable=False, comment='Фамилия юзера'),
        sa.Column('number', sa.Integer(), nullable=False, comment='Номер'),
        sa.Column('pin', sa.Integer(), nullable=True),
        sa.Column('status_code', sa.Integer(), nullable=True, comment='Код ошибки'),
        sa.Column('description', sa.String(), nullable=True, comment='Описание ошибки'),
        sa.Column('create_ts', sa.DateTime(), nullable=False, comment='Таймстемп создания (московское время)'),
        sa.PrimaryKeyConstraint('uuid'),
        schema='ODS_MARKETING',
        comment='Действия ботов принтера в вк и тг',
        info={'sensitive': False},
    )
    op.create_table(
        'rating_actions',
        sa.Column('uuid', sa.Uuid(), nullable=False),
        sa.Column('action', sa.String(), nullable=False, comment='Совершенное действие'),
        sa.Column('path_to', sa.String(), nullable=True, comment='Назначение перехода'),
        sa.Column('response_status_code', sa.Integer(), nullable=False),
        sa.Column('user_id', sa.Integer(), nullable=False),
        sa.Column('query', sa.String(), nullable=False, comment='Переданные параметры запроса'),
        sa.Column('create_ts', sa.DateTime(), nullable=False, comment='Таймстемп создания (московское время)'),
        sa.PrimaryKeyConstraint('uuid'),
        schema='ODS_MARKETING',
        comment='События в рейтинге',
        info={'sensitive': False},
    )
    op.create_group(
        "test_dwh_ods_marketing_read" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_read"
    )
    op.create_group(
        "test_dwh_ods_marketing_write" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_write"
    )
    op.create_group(
        "test_dwh_ods_marketing_all" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_all"
    )
    op.grant_on_schema(
        "test_dwh_ods_marketing_read" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_read",
        "ODS_MARKETING",
    )
    op.grant_on_schema(
        "test_dwh_ods_marketing_write" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_write",
        "ODS_MARKETING",
    )
    op.grant_on_schema(
        "test_dwh_ods_marketing_all" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_all",
        "ODS_MARKETING",
    )
    op.grant_on_table(
        "test_dwh_ods_marketing_read" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_read",
        ['SELECT'],
        '"ODS_MARKETING".frontend_actions',
    )
    op.grant_on_table(
        "test_dwh_ods_marketing_write" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_write",
        ['SELECT', 'UPDATE', 'DELETE', 'TRUNCATE', 'INSERT'],
        '"ODS_MARKETING".frontend_actions',
    )
    op.grant_on_table(
        "test_dwh_ods_marketing_all" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_all",
        ['ALL'],
        '"ODS_MARKETING".frontend_actions',
    )
    op.grant_on_table(
        "test_dwh_ods_marketing_read" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_read",
        ['SELECT'],
        '"ODS_MARKETING".rating_actions',
    )
    op.grant_on_table(
        "test_dwh_ods_marketing_write" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_write",
        ['SELECT', 'UPDATE', 'DELETE', 'TRUNCATE', 'INSERT'],
        '"ODS_MARKETING".rating_actions',
    )
    op.grant_on_table(
        "test_dwh_ods_marketing_all" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_all",
        ['ALL'],
        '"ODS_MARKETING".rating_actions',
    )
    op.grant_on_table(
        "test_dwh_ods_marketing_read" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_read",
        ['SELECT'],
        '"ODS_MARKETING".printer_actions',
    )
    op.grant_on_table(
        "test_dwh_ods_marketing_write" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_write",
        ['SELECT', 'UPDATE', 'DELETE', 'TRUNCATE', 'INSERT'],
        '"ODS_MARKETING".printer_actions',
    )
    op.grant_on_table(
        "test_dwh_ods_marketing_all" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_all",
        ['ALL'],
        '"ODS_MARKETING".printer_actions',
    )
    op.grant_on_table(
        "test_dwh_ods_marketing_read" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_read",
        ['SELECT'],
        '"ODS_MARKETING".printer_bots_actions',
    )
    op.grant_on_table(
        "test_dwh_ods_marketing_write" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_write",
        ['SELECT', 'UPDATE', 'DELETE', 'TRUNCATE', 'INSERT'],
        '"ODS_MARKETING".printer_bots_actions',
    )
    op.grant_on_table(
        "test_dwh_ods_marketing_all" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_all",
        ['ALL'],
        '"ODS_MARKETING".printer_bots_actions',
    )


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.revoke_on_table(
        "test_dwh_ods_marketing_all" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_all",
        ['ALL'],
        '"ODS_MARKETING".printer_bots_actions',
    )
    op.revoke_on_table(
        "test_dwh_ods_marketing_write" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_write",
        ['SELECT', 'UPDATE', 'DELETE', 'TRUNCATE', 'INSERT'],
        '"ODS_MARKETING".printer_bots_actions',
    )
    op.revoke_on_table(
        "test_dwh_ods_marketing_read" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_read",
        ['SELECT'],
        '"ODS_MARKETING".printer_bots_actions',
    )
    op.revoke_on_table(
        "test_dwh_ods_marketing_all" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_all",
        ['ALL'],
        '"ODS_MARKETING".printer_actions',
    )
    op.revoke_on_table(
        "test_dwh_ods_marketing_write" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_write",
        ['SELECT', 'UPDATE', 'DELETE', 'TRUNCATE', 'INSERT'],
        '"ODS_MARKETING".printer_actions',
    )
    op.revoke_on_table(
        "test_dwh_ods_marketing_read" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_read",
        ['SELECT'],
        '"ODS_MARKETING".printer_actions',
    )
    op.revoke_on_table(
        "test_dwh_ods_marketing_all" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_all",
        ['ALL'],
        '"ODS_MARKETING".rating_actions',
    )
    op.revoke_on_table(
        "test_dwh_ods_marketing_write" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_write",
        ['SELECT', 'UPDATE', 'DELETE', 'TRUNCATE', 'INSERT'],
        '"ODS_MARKETING".rating_actions',
    )
    op.revoke_on_table(
        "test_dwh_ods_marketing_read" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_read",
        ['SELECT'],
        '"ODS_MARKETING".rating_actions',
    )
    op.revoke_on_table(
        "test_dwh_ods_marketing_all" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_all",
        ['ALL'],
        '"ODS_MARKETING".frontend_actions',
    )
    op.revoke_on_table(
        "test_dwh_ods_marketing_write" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_write",
        ['SELECT', 'UPDATE', 'DELETE', 'TRUNCATE', 'INSERT'],
        '"ODS_MARKETING".frontend_actions',
    )
    op.revoke_on_table(
        "test_dwh_ods_marketing_read" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_read",
        ['SELECT'],
        '"ODS_MARKETING".frontend_actions',
    )
    op.revoke_on_schema(
        "test_dwh_ods_marketing_all" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_all",
        "ODS_MARKETING",
    )
    op.revoke_on_schema(
        "test_dwh_ods_marketing_write" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_write",
        "ODS_MARKETING",
    )
    op.revoke_on_schema(
        "test_dwh_ods_marketing_read" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_read",
        "ODS_MARKETING",
    )
    op.drop_table('rating_actions', schema='ODS_MARKETING')
    op.drop_table('printer_bots_actions', schema='ODS_MARKETING')
    op.drop_table('printer_actions', schema='ODS_MARKETING')
    op.drop_table('frontend_actions', schema='ODS_MARKETING')
    op.delete_group(
        "test_dwh_ods_marketing_all" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_all"
    )
    op.delete_group(
        "test_dwh_ods_marketing_write" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_write"
    )
    op.delete_group(
        "test_dwh_ods_marketing_read" if os.getenv("ENVIRONMENT") != "production" else "prod_dwh_ods_marketing_read"
    )
    op.drop_table_schema("ODS_MARKETING")
